<?php
namespace Ak\Image;

use Ak\Lib\File\File;
use Imagick;

/**
 * Slika.
 *
 * @package Ak\Image
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/image
 */
class Image extends File implements
    ImageInterface,
    ImagickAwareInterface
{
    /** @var Imagick */
    private $imagick;
    /** @var int */
    private $width;
    /** @var int */
    private $height;

    /**
     * Konstruktor.
     *
     * @param string|resource|Imagick $contents
     */
    public function __construct($contents = null)
    {
        if ($contents instanceof Imagick) {
            $this->imagick = $contents;
            $contents = $contents->getImageBlob();
        }

        parent::__construct($contents);
    }

    /**
     * Destruktor.
     */
    public function __destruct()
    {
        if ($this->imagick instanceof Imagick) {
            $this->imagick->clear();
        }
    }

    /**
     * Vraća širinu slike u pikselima.
     *
     * @return int
     */
    public function getWidth(): int
    {
        if (null === $this->width) {
            $imagick = $this->getImagick();
            $this->width = $imagick->getImageWidth();
        }

        return $this->width;
    }

    /**
     * Vraća visinu slike u pikselima.
     *
     * @return int
     */
    public function getHeight(): int
    {
        if (null === $this->height) {
            $imagick = $this->getImagick();
            $this->height = $imagick->getImageHeight();
        }

        return $this->height;
    }

    /** @noinspection PhpDocMissingThrowsInspection */

    /**
     * Vraća Imagick objekt u koji je učitana ova slika.
     *
     * @return Imagick
     */
    public function getImagick(): Imagick
    {
        if (null === $this->imagick) {
            /** @noinspection PhpUnhandledExceptionInspection */
            $this->imagick = new Imagick();
            /** @noinspection PhpUnhandledExceptionInspection */
            $this->imagick->readImageBlob($this->getContents());
        }

        return $this->imagick;
    }
}