<?php
namespace AkTest\Image;

use Ak\Image\Image;
use Imagick;
use PHPUnit\Framework\TestCase;

/**
 * Class ImageTest
 *
 * @package AkTest\Image
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/image
 */
final class ImageTest extends TestCase
{
    public function testCanDetectDimensions()
    {
        $image = new Image(fopen(__DIR__ . '/data/image.gif', 'r'));

        $this->assertEquals(320, $image->getWidth());
        $this->assertEquals(260, $image->getHeight());
    }

    /**
     * @throws \ImagickException
     */
    public function testCanBeCreatedFromImagickObject()
    {
        $imagick = new Imagick(__DIR__ . '/data/image.gif');
        $image = new Image($imagick);

        $this->assertSame($imagick, $image->getImagick());
        $this->assertEquals($imagick->getImageBlob(), $image->getContents());
    }

    /**
     * @expectedException \ImagickException
     */
    public function testWillDestroyImagickOnDestruct()
    {
        $imagick = new Imagick(__DIR__ . '/data/image.gif');
        /** @noinspection PhpUnusedLocalVariableInspection */
        $image = new Image($imagick);

        $this->assertNotEmpty($imagick->getImageBlob());
        $image = null;
        $imagick->getImageBlob();
    }
}